@@ -19,15 +19,14 @@ class SwitchbotPlugMini(SwitchbotDevice):
 
     async def turn_on(self) -> bool:
         """Turn device on."""
-        result = await self._sendcommand(PLUG_ON_KEY, self._retry_count)
+        result = await self._sendcommand(PLUG_ON_KEY)
         return result[1] == 0x80
 
     async def turn_off(self) -> bool:
         """Turn device off."""
-        result = await self._sendcommand(PLUG_OFF_KEY, self._retry_count)
+        result = await self._sendcommand(PLUG_OFF_KEY)
         return result[1] == 0x00
 
-    def is_on(self) -> Any:
+    def is_on(self) -> bool | None:
         """Return switch state from cache."""
-        # To get actual position call update() first.
         return self._get_adv_value("isOn")
